@@ -15,6 +15,7 @@ Functions to plot radar volume data
     plot_time_range
     plot_fixed_rng
     plot_fixed_rng_span
+    plot_fixed_rng_sun
     plot_cappi
     plot_traj
     plot_rhi_contour
@@ -28,6 +29,8 @@ Functions to plot radar volume data
 from warnings import warn
 
 import numpy as np
+
+
 from netCDF4 import num2date
 
 try:
@@ -58,7 +61,7 @@ import pyart
 from .plots_aux import get_colobar_label, get_norm, generate_fixed_rng_title
 from .plots_aux import generate_fixed_rng_span_title
 from .plots_aux import generate_complex_range_Doppler_title
-from .plots import plot_quantiles, plot_histogram, _plot_time_range
+from .plots import plot_quantiles, plot_histogram, _plot_time_range, _plot_sunscan
 
 from ..util.radar_utils import compute_quantiles_sweep, find_ang_index
 from ..util.radar_utils import compute_histogram_sweep
@@ -685,9 +688,13 @@ def plot_fixed_rng(radar, field_name, prdcfg, fname_list, azi_res=None,
 
             for i, azi in enumerate(azi_vec):
                 ind = find_ang_index(azi_1D, azi, ang_tol=ang_tol)
+
                 if ind is None:
                     continue
-                field_2D[i, j] = field_1D[ind]
+                try:
+                    field_2D[i, j] = field_1D[ind]
+                except ValueError:
+                    field_2D[i, j] = field_1D[ind][0]
     else:
         for i, azi in enumerate(azi_vec):
             field_1D = radar.fields[field_name]['data'][
@@ -935,6 +942,142 @@ def plot_fixed_rng_span(radar, field_name, prdcfg, fname_list, azi_res=None,
         figsize=[xsize, ysize], dpi=dpi)
 
 
+def plot_fixed_rng_sun(radar, field_name, sun_hits, prdcfg, fname_list, azi_res=None,
+                   ele_res=None, ang_tol=1., vmin=None, vmax=None):
+    """
+    plots a fixed range plot
+
+    Parameters
+    ----------
+    radar : radar object
+        The radar object containing the fixed range data
+    field_name : str
+        The name of the field to plot
+    sun_hits: dict
+        dictionary containing the sun hits data
+    prdcfg : dict
+        dictionary containing the product configuration
+    fname_list : list of str
+        list of names of the files where to store the plot
+    azi_res, ele_res : float
+        The nominal azimuth and elevation angle resolution [deg]
+    ang_tol : float
+        The tolerance between the nominal and the actual radar angle
+    vmin, vmax : float
+        Min and Max values of the color scale. If None it is going to be taken
+        from the Py-ART config files
+
+    Returns
+    -------
+    fname_list : list of str
+        list of names of the created plots
+
+    """
+    # Get radar azimuth angles within limits taking as reference
+    # the first elevation angle
+    fixed_rng = radar.range['data'][0]
+
+    if radar.scan_type == 'ppi':
+        ele_vec = np.sort(radar.fixed_angle['data'])
+        azi_vec = np.sort(
+            radar.azimuth['data'][radar.sweep_start_ray_index['data'][0]:
+                                  radar.sweep_end_ray_index['data'][0]+1])
+    else:
+        ele_vec = np.sort(
+            radar.elevation['data'][radar.sweep_start_ray_index['data'][0]:
+                                    radar.sweep_end_ray_index['data'][0]+1])
+        azi_vec = np.sort(radar.fixed_angle['data'])
+
+    # put data in a regular 2D grid
+    field_2D = np.ma.masked_all((azi_vec.size, ele_vec.size))
+    sweep_start_inds = radar.sweep_start_ray_index['data']
+    sweep_end_inds = radar.sweep_end_ray_index['data']
+
+    if radar.scan_type == 'ppi':
+        for j, ele in enumerate(ele_vec):
+            field_1D = radar.fields[field_name]['data'][
+                sweep_start_inds[j]:sweep_end_inds[j]+1]
+            azi_1D = radar.azimuth['data'][
+                sweep_start_inds[j]:sweep_end_inds[j]+1]
+
+            for i, azi in enumerate(azi_vec):
+                ind = find_ang_index(azi_1D, azi, ang_tol=ang_tol)
+                #print('IND: ',ind)
+                if ind is None:
+                    continue
+                #print('FIELD_1D: ',field_1D[ind])
+                field_2D[i, j] = field_1D[ind][0]
+    else:
+        for i, azi in enumerate(azi_vec):
+            field_1D = radar.fields[field_name]['data'][
+                sweep_start_inds[i]:sweep_end_inds[i]+1]
+            ele_1D = radar.elevation['data'][
+                sweep_start_inds[i]:sweep_end_inds[i]+1]
+
+            for j, ele in enumerate(ele_vec):
+                ind = find_ang_index(ele_1D, ele, ang_tol=ang_tol)
+                if ind is None:
+                    continue
+                field_2D[i, j] = field_1D[ind]
+
+    # get limits of angle bins
+    if radar.scan_type == 'ppi':
+        if azi_res is None:
+            azi_res = np.median(azi_vec[1:]-azi_vec[0:-1])
+            if radar.ray_angle_res is not None:
+                azi_res = np.min(
+                    [radar.ray_angle_res['data'][0], azi_res])
+
+        azi_vec = np.append(azi_vec-azi_res/2., azi_vec[-1]+azi_res/2.)
+
+        if ele_res is None:
+            ele_res = np.median(ele_vec[1:]-ele_vec[0:-1])
+            if radar.instrument_parameters is not None:
+                if 'radar_beam_width_h' in radar.instrument_parameters:
+                    bwidth = radar.instrument_parameters[
+                        'radar_beam_width_h']['data'][0]
+                    ele_res = np.min([bwidth, ele_res])
+                elif 'radar_beam_width_v' in radar.instrument_parameters:
+                    bwidth = radar.instrument_parameters[
+                        'radar_beam_width_v']['data'][0]
+                    ele_res = np.min([bwidth, ele_res])
+
+        ele_vec = np.append(ele_vec-ele_res/2., ele_vec[-1]+ele_res/2.)
+    else:
+        if ele_res is None:
+            ele_res = np.median(ele_vec[1:]-ele_vec[0:-1])
+            if radar.ray_angle_res is not None:
+                ele_res = np.min(
+                    [radar.ray_angle_res['data'][0], ele_res])
+
+        ele_vec = np.append(ele_vec-ele_res/2., ele_vec[-1]+ele_res/2.)
+
+        if azi_res is None:
+            azi_res = np.median(azi_vec[1:]-azi_vec[0:-1])
+            if radar.instrument_parameters is not None:
+                if 'radar_beam_width_h' in radar.instrument_parameters:
+                    bwidth = radar.instrument_parameters[
+                        'radar_beam_width_h']['data'][0]
+                    azi_res = np.min([bwidth, azi_res])
+                elif 'radar_beam_width_v' in radar.instrument_parameters:
+                    bwidth = radar.instrument_parameters[
+                        'radar_beam_width_v']['data'][0]
+                    azi_res = np.min([bwidth, azi_res])
+
+        azi_vec = np.append(azi_vec-azi_res/2., azi_vec[-1]+azi_res/2.)
+
+    titl = generate_fixed_rng_title(radar, field_name, fixed_rng)
+
+    dpi = prdcfg['ppiImageConfig'].get('dpi', 72)
+    xsize = prdcfg['ppiImageConfig'].get('xsize', 10)
+    ysize = prdcfg['ppiImageConfig'].get('ysize', 8)
+
+    return _plot_sunscan(
+        azi_vec, ele_vec, field_2D, sun_hits, field_name, fname_list, titl=titl,
+        xlabel='azimuth (deg)', ylabel='elevation (deg)',
+        figsize=[xsize, ysize], vmin=vmin, vmax=vmax, dpi=dpi)
+
+
 def plot_cappi(radar, field_name, altitude, prdcfg, fname_list,
                beamwidth=1., beam_spacing=1., save_fig=True):
     """
